@@ -38,6 +38,7 @@
 #include "table.h"
 #include "callbacks.h"
 #include "user-settings.h"
+#include "user-password.h"
 #include "privileges-table.h"
 #include "groups-table.h"
 #include "group-settings.h"
@@ -46,11 +47,21 @@
 
 extern GstTool *tool;
 
-void   on_edit_user_passwd  (GtkButton *button,
-                             gpointer   user_data);
 
 void   on_user_settings_enable_account  (GtkButton *button,
                                          gpointer   user_data);
+void   on_user_new_name_changed         (GtkEditable *user_name,
+                                         gpointer     user_data);
+void   on_user_new_login_changed        (GtkComboBox *login_combo,
+                                         gpointer     user_data);
+void   on_user_new                      (GtkButton *button,
+                                         gpointer   user_data);
+void   on_edit_user_name                (GtkButton *button,
+                                         gpointer   user_data);
+void   on_edit_user_profile             (GtkButton *button,
+                                         gpointer   user_data);
+void   on_edit_user_advanced            (GtkButton *button,
+                                         gpointer   user_data);
 
 
 static gboolean
@@ -113,7 +124,7 @@ check_user_delete (OobsUser *user)
 		                                            _("Files owned by user %s in <tt>%s</tt> can be completely "
 		                                              "removed if you don't need them anymore. You may want to "
 		                                              "back them up before deleting the account, or keep them "
-		                                              "so that and administrator can save them later."),
+		                                              "so that an administrator can save them later."),
 		                                            oobs_user_get_login_name (user),
 		                                            oobs_user_get_home_directory (user));
 
@@ -331,7 +342,7 @@ user_settings_show (OobsUser *user)
 	if (oobs_user_get_password_empty (user))
 		/* TRANSLATORS: This applies to a password. */
 		gtk_label_set_text (GTK_LABEL (passwd_label), _("None"));
-	else if (oobs_user_is_in_group (user, group))
+	else if (group && oobs_user_is_in_group (user, group))
 		/* TRANSLATORS:  This applies to a password. Keep the string short. */
 		gtk_label_set_text (GTK_LABEL (passwd_label), _("Not asked on login"));
 	else
@@ -589,37 +600,6 @@ check_profile (OobsUser *user, GstUserProfile *profile)
 	return TRUE;
 }
 
-/*
- * Callback for user_settings_enable_account: unlock account and commit changes.
- */
-void
-on_user_settings_enable_account  (GtkButton *enable_button,
-                                  gpointer   user_data)
-{
-	GtkWidget *disabled_image;
-	GtkWidget *disabled_label;
-	OobsUser *user;
-
-	if (!gst_tool_authenticate (tool, GST_USERS_TOOL (tool)->users_config))
-		return;
-
-	user = users_table_get_current ();
-	oobs_user_set_password_disabled (user, FALSE);
-
-	if (gst_tool_commit (tool, OOBS_OBJECT (user)) == OOBS_RESULT_OK) {
-		disabled_image = gst_dialog_get_widget (tool->main_dialog,
-		                                        "user_settings_disabled_account_image");
-		disabled_label = gst_dialog_get_widget (tool->main_dialog,
-		                                        "user_settings_disabled_account");
-
-		gtk_widget_hide (disabled_image);
-		gtk_widget_hide (disabled_label);
-		gtk_widget_hide (GTK_WIDGET (enable_button));
-	}
-
-	g_object_unref (user);
-}
-
 /*
  * Callback for user_new_name entry: on every change, fill the combo entry
  * with proposed logins. Also update validate button's sensitivity if name is empty.
@@ -918,9 +898,11 @@ on_user_new (GtkButton *button, gpointer user_data)
 	GtkTreeModel *model;
 	GtkTreePath *user_path;
 	OobsUser *user;
+	OobsGroup *main_group;
 	const char *fullname, *login;
 	GstUserProfile *profile;
 	OobsUsersConfig *users_config;
+	OobsGroupsConfig *groups_config;
 	OobsResult result;
 	gboolean encrypt;
 
@@ -936,6 +918,7 @@ on_user_new (GtkButton *button, gpointer user_data)
 	encrypted_home = gst_dialog_get_widget (tool->main_dialog, "user_new_encrypted_home");
 
 	users_config = OOBS_USERS_CONFIG (GST_USERS_TOOL (tool)->users_config);
+	groups_config = OOBS_GROUPS_CONFIG (GST_USERS_TOOL (tool)->groups_config);
 
 	/* clear any text, colors or icon left */
 	gtk_entry_set_text (GTK_ENTRY (user_name), "");
@@ -947,6 +930,8 @@ on_user_new (GtkButton *button, gpointer user_data)
 	/* Show the encrypt home check box if supported */
 	if (oobs_users_config_get_encrypted_home_support (users_config))
 	    gtk_widget_show (encrypted_home);
+	else
+	    gtk_widget_hide (encrypted_home);
 
 	gtk_window_set_focus (GTK_WINDOW (user_new_dialog), user_name);
 
@@ -972,6 +957,20 @@ on_user_new (GtkButton *button, gpointer user_data)
 	user = oobs_user_new (login);
 	oobs_user_set_full_name (user, fullname);
 	oobs_user_set_encrypted_home (user, encrypt);
+	oobs_user_set_home_flags (user, OOBS_USER_CHOWN_HOME);
+
+	/* Emptying password and disabling account allows enabling it more easily if asked */
+	oobs_user_set_password_empty (user, TRUE);
+	oobs_user_set_password_disabled (user, TRUE);
+
+	/* If the user group already exists and /etc/adduser.conf USERGROUPS option is yes,
+	 * then adduser will fail, and the backends don't allow reporting that error.
+	 * So assume we want the user to be in that group. */
+	main_group = oobs_groups_config_get_from_name (groups_config, login);
+	if (main_group) {
+		oobs_user_set_main_group (user, main_group);
+		g_object_unref (main_group);
+	}
 
 	g_return_if_fail (user != NULL);
 
@@ -981,7 +980,7 @@ on_user_new (GtkButton *button, gpointer user_data)
 
 	/* We need to know about this user before adding it, else we won't be aware
 	 * that we triggered the commit, and we will show a "Reload config?" dialog. */
-	gst_tool_add_configuration_object (GST_TOOL (tool), OOBS_OBJECT (user));
+	gst_tool_add_configuration_object (GST_TOOL (tool), OOBS_OBJECT (user), FALSE);
 
 	/* Commit both user and groups config because of possible memberships
 	 * added by the profile. Avoid showing the new user or trying to commit
@@ -1056,6 +1055,7 @@ on_edit_user_name (GtkButton *button, gpointer user_data)
 	OobsUser *user;
 	const char *fullname;
 	gboolean is_self;
+	OobsResult result;
 
 	user = users_table_get_current ();
 
@@ -1093,12 +1093,14 @@ on_edit_user_name (GtkButton *button, gpointer user_data)
 		oobs_user_set_full_name (user, fullname);
 
 		if (is_self)
-			gst_tool_commit (tool, GST_USERS_TOOL (tool)->self_config);
+			result = gst_tool_commit (tool, GST_USERS_TOOL (tool)->self_config);
 		else
-			gst_tool_commit (tool, OOBS_OBJECT (user));
+			result = gst_tool_commit (tool, OOBS_OBJECT (user));
 
-		gtk_label_set_text (GTK_LABEL (user_settings_real_name), fullname);
-		users_table_update_current ();
+		if (result == OOBS_RESULT_OK) {
+			gtk_label_set_text (GTK_LABEL (user_settings_real_name), fullname);
+			users_table_update_current ();
+		}
 	}
 
 	g_object_unref (user);
@@ -1179,6 +1181,8 @@ on_edit_user_profile (GtkButton *button, gpointer user_data)
 		  if (response == GTK_RESPONSE_OK) {
 			  if (gst_tool_commit (tool, OOBS_OBJECT (user)) == OOBS_RESULT_OK)
 				  gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config);
+
+			  user_settings_show (user);
 		  }
 	  }
 
@@ -1237,6 +1241,10 @@ on_edit_user_advanced (GtkButton *button, gpointer user_data)
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_uid");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), oobs_user_get_uid (user));
 
+	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_locked_account");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), oobs_user_get_password_disabled (user));
+
+
 	/* show a notice if the user is logged in */
 	uid_notice = gst_dialog_get_widget (tool->main_dialog, "user_settings_uid_disabled");
 
@@ -1289,13 +1297,16 @@ on_edit_user_advanced (GtkButton *button, gpointer user_data)
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_uid");
 	oobs_user_set_uid (user, gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget)));
 
+	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_locked_account");
+	oobs_user_set_password_disabled (user, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)));
+
 	privileges_table_save (user);
 
 	/* Get main group */
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_group");
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
 
-	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter) != -1) {
+	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter)) {
 		gtk_tree_model_get (model, &iter,
 				    COL_GROUP_OBJECT, &main_group,
 				    -1);
@@ -1306,8 +1317,10 @@ on_edit_user_advanced (GtkButton *button, gpointer user_data)
 		oobs_user_set_main_group (user, NULL);
 
 
-	if (gst_tool_commit (tool, OOBS_OBJECT (user)) == OOBS_RESULT_OK)
+	if (gst_tool_commit (tool, OOBS_OBJECT (user)) == OOBS_RESULT_OK) {
 		gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config);
+		user_settings_show (user);
+	}
 
 	g_object_unref (user);
 }
